@@ -10,7 +10,7 @@
 # Note:
 # none
 #
-# Copyright (c) 2012-2015, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2017, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 use warnings;
@@ -28,12 +28,12 @@ Usage:
 CrmFilePath      reflect the crm file in the case of first startup
 
 Options:
-  -h, --help       show this help, then exit
-  -v, --version    show this version, then exit
+  -h, --help       show this help, then quit
+  -v, --version    show this version, then quit
 
 _MASTERSTART_USAGE_
 
-    MASTERSTART_MS0001  => "The command \"Ctrl+C\" is invalid request.\n",
+    MASTERSTART_MS0001  => "Ctrl-C is ignored.\n",
     MASTERSTART_MS0002  => "No such crm file specified in the argument.\n",
     MASTERSTART_MS0004  => "Failed to read crm file.\n",
     MASTERSTART_MS0007  => "[0]. Checking Pacemaker and Corosync has stopped\n",
@@ -66,28 +66,36 @@ _MASTERSTART_USAGE_
                            "Should stop Pacemaker so check the content of \"[0]\".\n",
     
     MASTERSTART_MS0033  => "Should specify the parameter of \"[1]\" of ResourceID (\"[0]\") in crm file.\n",
+    MASTERSTART_MS0034  => "This database cluster is incompletely rewinded by pg-rex_slave_start. Startup failed.\n",
 
     SLAVESTART_USAGE  => <<_SLAVESTART_USAGE_,
-PG-REX standby start tool
-This is executed on the node that will start as a standby.
+PG-REX single-step starter  for slave node
+Run this script on the node to be slave to start.
 
 Usage:
-  pg-rex_slave_start [-n][-f][-c][-s][-o OPTIONS][-h][-v]
+  pg-rex_slave_start [[-n] [-r] [-b | -f] | -c] [-d] [-s] [-o OPTIONS] [-h] [-v]
 
 Options:
-  -n, --nobasebackup              start without taking a base backup from master
-  -f, --force                     execute without contacts
-  -c, --check-only                execute until confirmation of database cluster
-                                  state
-  -s, --shared-archive-directory  Specify state that archive directory is shared
-  -o, --options=OPTIONS           command line options for internally executed
-                                  pg_basebackup
-  -h, --help                      show this help, then exit
-  -v, --version                   show this version, then exit
+  -n, --normal                    start this node as it is as slave. when
+                                  specified along with the options -r, -b,
+                                  the first available option is chosen in
+                                  the order of -n, -r, -b
+  -r, --rewind                    start this node as slave after running
+                                  pg_rewind
+  -b, --basebackup                start this node as slave from a new basebackup
+                                  taken from the peer node as the master
+  -f, --force                     the same as -b option. obsolete
+  -d, --dry-run                   run without changing data and executing nodes
+  -c, --check-only                show the condition of database clusters
+  -s, --shared-archive-directory  assume that master and slave share the same
+                                  WAL archive directory
+  -o, --options=OPTIONS           pass OPTIONS to pg_basebackup
+  -h, --help                      show this help, then quit
+  -v, --version                   show the version, then quit
 
 _SLAVESTART_USAGE_
 
-    SLAVESTART_MS0001   => "The command \"Ctrl+C\" is invalid request.\n",
+    SLAVESTART_MS0001   => "Ctrl-C is ignored.\n",
     SLAVESTART_MS0002   => "Same authkey file with the another node has not been placed: [0]\n",
     SLAVESTART_MS0004   => "[0]. Checking Pacemaker and Corosync has stopped\n",
     SLAVESTART_MS0005   => "...[NG]\n",
@@ -102,9 +110,6 @@ _SLAVESTART_USAGE_
                            "In the case, this node may have previously started as a master.\n".
                            "Should check whether you really want to start as a standby.\n",
     SLAVESTART_MS0015   => "[0]. Taking a base backup from master\n",
-    SLAVESTART_MS0016   => "This node takes a base backup from master.\n".
-                           "Are you sure? (y/n) ",
-    SLAVESTART_MS0017   => "Exit.\n",
     SLAVESTART_MS0018   => "Failed to execute readlink command.\n",
     SLAVESTART_MS0019   => "[0]. Synchronizing with the archive directory on the master\n",
     SLAVESTART_MS0020   => "[0]. Deleting files in [1]\n",
@@ -113,8 +118,6 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0024   => "Resource has failed while the startup of the Pacemaker.\n".
                            "If you check details of Pacemaker status, please execute crm_mon command.\n",
     SLAVESTART_MS0029   => "Standby has started on the node ([0]).\n",
-    SLAVESTART_MS0030   => "root@[0]'s password:",
-    SLAVESTART_MS0031   => "\nPassword has been entered.\n",
     SLAVESTART_MS0032   => "Can not continue processing because file exists in archive directory: [0]\n",
     SLAVESTART_MS0033   => "Database cluster does not exist.\n",
     SLAVESTART_MS0034   => "[0]. Checking the status of database cluster\n",
@@ -124,7 +127,7 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0038   => "TimeLineID on this node is larger than another ([0] > [1]).\n",
     SLAVESTART_MS0039   => "Could not find wal file on this node: [0]\n",
     SLAVESTART_MS0040   => "Could not find wal file on another node: [0]\n",
-    SLAVESTART_MS0041   => "The location of xlog on this node is progressing than another ([0] > [1]).\n",
+    SLAVESTART_MS0041   => "This node is advancing in XLOG location against the peer node ([0] > [1]).\n",
     SLAVESTART_MS0042   => "Could not find latest history file on another node: [0]\n",
     SLAVESTART_MS0043   => "There are no history that has passed through TimeLineID on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
     SLAVESTART_MS0044   => "There are no history that has passed through the location of xlog on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
@@ -135,6 +138,34 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0048   => "[0] is not running.\n".
                            "If you check details of Pacemaker status, please execute crm_mon command.\n",
     SLAVESTART_MS0049   => "Failed to process archived history file (Unexpected extension: [0]).\n",
+    SLAVESTART_MS0050   => "[0].[1] Checking if this node can start without change\n",
+    SLAVESTART_MS0051   => "[0].[1] Checking if this node can start after running pg_rewind\n",
+    SLAVESTART_MS0052   => "[0].[1] Checking if it is ready to run pg_basebackup\n",
+    SLAVESTART_MS0053   => "Promoted LSNs for TimelineID = [0] on both nodes are not identical.\n",
+    SLAVESTART_MS0054   => "recovery.conf exists on this node: [0]\n",
+    SLAVESTART_MS0055   => "full_page_writes on the peer node should be 'on'.\n",
+    SLAVESTART_MS0056   => "This database cluster must be initialized with --data-checksums, otherwise wal_log_hints must be 'on'.\n",
+    SLAVESTART_MS0057   => "pg_rewind is not available, try the other choices.\n",
+    SLAVESTART_MS0058   => "\nNone of the specified methods are able to be performed.\n",
+    SLAVESTART_MS0059   => "\nFollowing methods are available to start this node as standby\n",
+    SLAVESTART_MS0060   => "n) Start as it is\n",
+    SLAVESTART_MS0061   => "r) Start after running pg_rewind\n",
+    SLAVESTART_MS0062   => "b) Start from a new base backup\n",
+    SLAVESTART_MS0063   => "q) quit\n",
+    SLAVESTART_MS0064   => "Make a choice among the options ([0]) ",
+    SLAVESTART_MS0065   => "quit starting this node.\n",
+    SLAVESTART_MS0066   => "Invalid value.\n",
+    SLAVESTART_MS0067   => "\nStarting the database as it is.\n",
+    SLAVESTART_MS0068   => "\nStarting after performing pg_rewind.\n",
+    SLAVESTART_MS0069   => "\nStarting from a new base backup.\n",
+    SLAVESTART_MS0070   => "[0]. Rewinding the database cluster\n",
+    SLAVESTART_MS0071   => "Running pg_rewind.\n",
+    SLAVESTART_MS0072   => "Unable to rewind to the promoted point of the peer node.pg_rewind not available.\n",
+    SLAVESTART_MS0073   => "Failed to establish an ssh connection ([0]) - Aborting rewind\n",
+    SLAVESTART_MS0074   => "pg_rewind failed to connect to the peer\n - TCP Forwarding may be disabled in sshd_config on the peer server\n",
+    SLAVESTART_MS0075   => "This database cluster is incompletely rewinded by pg-rex_slave_start.\n",
+    SLAVESTART_MS0076   => "WAL files with future XLOG location of the peer node found in archive directory.\n",
+    SLAVESTART_MS0099   => "Internal Error.\n",
 
     STOP_USAGE  => <<_STOP_USAGE_,
 PG-REX stop tool
@@ -145,12 +176,12 @@ Usage:
 
 Options:
   -f, --fast       stop without executing CHECKPOINT and sync command
-  -h, --help       show this help, then exit
-  -v, --version    show this version, then exit
+  -h, --help       show this help, then quit
+  -v, --version    show this version, then quit
 
 _STOP_USAGE_
 
-    STOP_MS0001         => "The command \"Ctrl+C\" is invalid request.\n",
+    STOP_MS0001         => "Ctrl-C is ignored.\n",
     STOP_MS0004         => "Pacemaker and Corosync has already stopped.\n",
     STOP_MS0005         => "Could not check the status of PostgreSQL.\n".
                            "Stopping Pacemaker.\n",
@@ -166,7 +197,7 @@ _STOP_USAGE_
     STOP_MS0015         => "Pacemaker has stopped on the node ([0]).\n",
     STOP_MS0016         => "[0] has stopped on the node ([1]).\n",
     STOP_MS0018         => "Standby has already started.\n",
-    STOP_MS0019         => "we recommand to use pg-rex_switchover command when you want to stop master with the purpose of switchover.\n",
+    STOP_MS0019         => "we recommend to use pg-rex_switchover command when you want to stop master with the purpose of switchover.\n",
     STOP_MS0020         => "If you continue with this operation, then a failover occurs, but are you sure? (y/N) ",
 
     ARCHDELETE_USAGE  => <<_ARCDELETE_USAGE_,
@@ -182,21 +213,21 @@ BasebackupPath  the fullpath of remote server that exists a base backup
     Caution:  You will not be able to use a base backup older than one specified.
 
 Options:
-  -m, --move                         execute as a mv mode
-  -r, --remove                       execute as a rm mode
-  (You must specify either mv mode or rm.)
+  -m, --move                         execute as a move mode
+  -r, --remove                       execute as a remove mode
+  (You must specify either move mode or remove.)
   -f, --force                        execute without contacts
   -D, --dbcluster=DBclusterFilepath  the fullpath of database cluster
-  -h, --help                         show this help, then exit
-  -v, --version                      show this version, then exit
+  -h, --help                         show this help, then quit
+  -v, --version                      show this version, then quit
 
 _ARCDELETE_USAGE_
 
-    ARCHDELETE_MS0001   => "The command \"Ctrl+C\" is invalid request.\n",
-    ARCHDELETE_MS0002   => "Should specify mv mode or rm in the argument.\n",
+    ARCHDELETE_MS0001   => "Ctrl-C is ignored.\n",
+    ARCHDELETE_MS0002   => "Should specify move mode or remove in the argument.\n",
     ARCHDELETE_MS0003   => "\n**** 1. Ready to run ****\n",
-    ARCHDELETE_MS0004   => "Running mv mode.\n",
-    ARCHDELETE_MS0005   => "Running rm mode.\n",
+    ARCHDELETE_MS0004   => "Running move mode.\n",
+    ARCHDELETE_MS0005   => "Running remove mode.\n",
     ARCHDELETE_MS0006   => "The input format of the backup path is invalid : \"[0]\"\n",
     ARCHDELETE_MS0007   => "Please input a remote server name that has a base backup.\n".
                            "(If empty, set \"localhost\")\n".
@@ -206,7 +237,7 @@ _ARCDELETE_USAGE_
                            "(If empty, set no backup path.\n".
                            " In the case, you cannot use a base backup older than one specified because the archive log is removed.)\n".
                            "> ",
-    ARCHDELETE_MS0010   => "The input format of the fullpath of ths base backup is invalid : \"[0]\"\n",
+    ARCHDELETE_MS0010   => "The input format of the fullpath of this base backup is invalid : \"[0]\"\n",
     ARCHDELETE_MS0011   => "Remote server \"[0]\", Backup path\"[1]\".\n".
                            "Are you sure? (y/N) : ",
     ARCHDELETE_MS0012   => "Exit.\n",
@@ -235,11 +266,11 @@ _ARCDELETE_USAGE_
     ARCHDELETE_MS0036   => "Failed to change the owner of the directory where you want to move the archive log (\"[0]\").\n",
     ARCHDELETE_MS0037   => "Created the directory where you want to move the archive log.\n",
     ARCHDELETE_MS0038   => "Failed to move the file (\"[0]\").\n",
-    ARCHDELETE_MS0039   => " -- mv -- [0] \n",
+    ARCHDELETE_MS0039   => " -- move -- [0] \n",
     ARCHDELETE_MS0040   => "Succeeded moving the archive log.\n".
                            "These are in the directory (\"[0]\").\n",
     ARCHDELETE_MS0041   => "Failed to remove the file (\"[0]\").\n",
-    ARCHDELETE_MS0042   => " -- rm -- [0] \n",
+    ARCHDELETE_MS0042   => " -- remove -- [0] \n",
     ARCHDELETE_MS0043   => "Succeeded removing the archive log.\n",
     ARCHDELETE_MS0044   => "Failed to get DB cluster path.\n".
                            "Should specify the fullpath of DB cluster with \"-D\" option.\n",
@@ -253,12 +284,12 @@ Usage:
   pg-rex_switchover [-h][-v]
 
 Options:
-  -h, --help      show this help, then exit
-  -v, --version   show this version, then exit
+  -h, --help      show this help, then quit
+  -v, --version   show this version, then quit
 
 _SWITCHOVER_USAGE_
 
-    SWITCHOVER_MS0001   => "The command \"Ctrl+C\" is invalid request.\n",
+    SWITCHOVER_MS0001   => "Ctrl-C is ignored.\n",
     SWITCHOVER_MS0002   => "**** Ready to run ****\n",
     SWITCHOVER_MS0003   => "[0]. Reading pg-rex_tools.conf and get both node names.\n",
     SWITCHOVER_MS0004   => "...[OK]\n",
@@ -267,7 +298,7 @@ _SWITCHOVER_USAGE_
     SWITCHOVER_MS0009   => "Can not switchover because the cluster status does not meet the following conditions.\n".
                            " (1) Pacemaker, Corosync and PostgreSQL is running on both nodes\n".
                            " (2) Master and standby are present\n".
-                           " (3) PostgreSQL is the state of syncronous replication\n",
+                           " (3) PostgreSQL is the state of synchronous replication\n",
     SWITCHOVER_MS0010   => "[ Current cluster status ]\n",
     SWITCHOVER_MS0011   => "[ Cluster status of current and after switchover ]\n",
     SWITCHOVER_MS0012   => "Availability is not guaranteed during executing to switchover.\n",
@@ -333,7 +364,7 @@ _SWITCHOVER_USAGE_
     COMMON_MS0036       => "Not found PostgreSQL commands in specified PGPATH ([0]).\n".
                            "Should specify PGPATH correctly in pg-rex_tools.conf.\n",
     COMMON_MS0037       => "PostgreSQL [0] is not supported.\n".
-                           "Please use version 9.4.\n",
+                           "Please use version 9.4 or 9.5.\n",
     COMMON_MS0038       => "Pacemaker [0] is not supported.\n".
                            "Please use version 1.1.\n",
     COMMON_MS0039       => "Not found network interface to correspond to bindnetaddr ([1]) on [0].\n",
