@@ -10,7 +10,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2015, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2017, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 use warnings;
@@ -54,10 +54,10 @@ _MASTERSTART_USAGE_
     MASTERSTART_MS0020  => "[0]. crm ファイルの反映\n",
     MASTERSTART_MS0021  => "Pacemaker 起動確認処理のタイムアウト時間([0]秒)を経過したためスクリプトを終了します\n".
                            "[1] が起動していません\n".
-                           "Pacemaker の状態の詳細は、crm_mon コマンドを実行して確認してください\n",
+                           "Pacemaker の状態の詳細は、crm_mon コマンドで確認してください\n",
     MASTERSTART_MS0022  => "[0]. Master の起動確認\n",
     MASTERSTART_MS0023  => "Pacemaker の起動中にリソース故障が発生しました\n".
-                           "Pacemaker の状態の詳細は、crm_mon コマンドを実行して確認してください\n",
+                           "Pacemaker の状態の詳細は、crm_mon コマンドを用いて確認してください\n",
     MASTERSTART_MS0026  => "ノード([0])が Master として起動しました\n",
     MASTERSTART_MS0027  => "[0]. Master として稼働することが出来るかを確認\n",
     MASTERSTART_MS0028  => "自身のノードの [0]-data-status の値が \"[1]\" になっています\n".
@@ -69,77 +69,106 @@ _MASTERSTART_USAGE_
     MASTERSTART_MS0032  => "crm ファイルの Pacemaker への反映に失敗したためスクリプトを終了します\n".
                            "Pacemaker を停止し、[0] の内容を確認してください\n",
     MASTERSTART_MS0033  => "crm ファイルにリソース ID \"[0]\" の \"[1]\" のパラメータが存在していません\n",
+    MASTERSTART_MS0034  => "pg-rex_slave_startで巻き戻しに失敗したDBクラスタのため起動できません。\n",
 
     SLAVESTART_USAGE  => <<_SLAVESTART_USAGE_,
 PG-REX を Slave として起動するツールです
 Slave として起動したいノードで実行します
 
 Usage:
-  pg-rex_slave_start [-n] [-f] [-c] [-s] [-o OPTIONS] [-h] [-v]
+  pg-rex_slave_start [[-n] [-r] [-b | -f] | -c] [-d] [-s] [-o OPTIONS] [-h] [-v]
 
 Options:
-  -n, --nobasebackup              Master からベースバックアップを取得せずに
-                                  Slave を起動します
-  -f, --force                     Slave の起動を問い合わせ無しで実行します
+  -n, --normal                    現在のDBクラスタを使用して Slave を起動します
+  -r, --rewind                    現在のDBクラスタに相手 (Master) ノードと
+                                  同期したうえでレプリケーションを行えるように、
+                                  巻き戻し後、Slave を起動します
+  -b, --basebackup                相手ノードをMasterとしてベースバックアップを
+                                  取得後、Slave として起動します
+  -f, --force                     -b オプションに同じ。廃止予定
+  -d, --dry-run                   データの変更とノードの起動の実行を伴わず、
+                                  表示のみを行います
   -c, --check-only                DB クラスタの状態確認までを実施します
   -s, --shared-archive-directory  Master と Slave でアーカイブディレクトリを
-                                  共有していることを指定します
-  -o, --options=OPTIONS           ベースバックアップ取得時に実行する
-                                  pg_basebackupに渡すオプションを指定します
+                                  共有しているものとして動作します
+  -o, --options=OPTIONS           pg_basebackup に渡すオプションを指定します
   -h, --help                      Usage を表示して終了します
   -v, --version                   バージョン情報を表示して終了します
 
 _SLAVESTART_USAGE_
     
     SLAVESTART_MS0001   => "Ctrl+C は本プログラムでは無効です\n",
-    SLAVESTART_MS0002   => "相手のノードと同じクラスタ認証設定ファイルが配置されていません: [0]\n",
+    SLAVESTART_MS0002   => "相手のノードと同じクラスタ認証ファイルを配置する必要があります: [0]\n",
     SLAVESTART_MS0004   => "[0]. Pacemaker および Corosync が停止していることを確認\n",
     SLAVESTART_MS0005   => "...[NG]\n",
     SLAVESTART_MS0006   => "自身のノードで Pacemaker または Corosync が稼働しています\n".
-                           "Slave 起動処理を中止します\n",
+                           "Slave の起動処理を中止します\n",
     SLAVESTART_MS0007   => "...[OK]\n",
     SLAVESTART_MS0008   => "[0]. 稼働中の Master が存在していることを確認\n",
     SLAVESTART_MS0010   => "相手のノードで Master が稼働していません\n".
-                           "Slave 起動処理を中止します\n",
+                           "Slave の起動処理を中止します\n",
     SLAVESTART_MS0011   => "[0]. IC-LAN が接続されていることを確認\n",
     SLAVESTART_MS0012   => "IC-LAN の接続応答がありません\n",
-    SLAVESTART_MS0013   => "[0]. 起動禁止フラグの存在を確認\n",
+    SLAVESTART_MS0013   => "[0]. 起動禁止フラグが存在しないことを確認\n",
     SLAVESTART_MS0014   => "起動禁止フラグ \"[0]\" が存在するため Slave の起動処理を中止します\n".
                            "前回停止時に Master として稼働していた可能性があるので Slave として起動していいかどうかを確認してください\n",
     SLAVESTART_MS0015   => "[0]. Master からベースバックアップ取得\n",
-    SLAVESTART_MS0016   => "ベースバックアップの取得を行います\n".
-                           "よろしいでしょうか？ (y/n) ",
-    SLAVESTART_MS0017   => "スクリプトを終了します\n",
     SLAVESTART_MS0018   => "readlink コマンドの実行に失敗しました\n",
     SLAVESTART_MS0019   => "[0]. Master のアーカイブディレクトリと同期\n",
     SLAVESTART_MS0020   => "[0]. [1] 配下のファイルを削除\n",
     SLAVESTART_MS0021   => "[0]. Slave の起動 (アーカイブリカバリ対象 WAL セグメント数: [1])\n",
     SLAVESTART_MS0022   => "[0]. Slave の起動確認\n",
     SLAVESTART_MS0024   => "Pacemaker の起動中にリソース故障が発生しました\n".
-                           "Pacemaker の状態の詳細は、crm_mon コマンドを実行して確認してください\n",
+                           "Pacemaker の状態の詳細は、crm_mon コマンドで確認してください\n",
     SLAVESTART_MS0029   => "ノード([0])が Slave として起動しました\n",
-    SLAVESTART_MS0030   => "root@[0]'s password:",
-    SLAVESTART_MS0031   => "\nパスワードが入力されました\n",
     SLAVESTART_MS0032   => "アーカイブディレクトリにファイルが存在するため処理を継続できません: [0]\n",
     SLAVESTART_MS0033   => "DB クラスタが存在していません\n",
     SLAVESTART_MS0034   => "[0]. DB クラスタの状態を確認\n",
-    SLAVESTART_MS0035   => "DB クラスタのバージョンが取得できませんでした\n",
+    SLAVESTART_MS0035   => "DB クラスタのバージョンが取得できません\n",
     SLAVESTART_MS0036   => "DB クラスタのバージョン ([0]) が PostgreSQL サーバのバージョン ([1]) と一致していません\n",
     SLAVESTART_MS0037   => "自身のノードと相手のノードでデータベース識別子が異なっています ([0] != [1])\n",
-    SLAVESTART_MS0038   => "自身のノードの TimeLineID のほうが相手のノードの TimeLineID よりも大きくなっています ([0] > [1])\n",
+    SLAVESTART_MS0038   => "自身のノードの タイムラインID のほうが相手のノードの タイムラインID よりも大きくなっています ([0] > [1])\n",
     SLAVESTART_MS0039   => "自身のノードに WAL ファイルが存在しません: [0]\n",
     SLAVESTART_MS0040   => "相手のノードに WAL ファイルが存在しません: [0]\n",
     SLAVESTART_MS0041   => "自身のノードの XLOG の位置のほうが相手のノードの XLOG の位置よりも進んでいます ([0] > [1])\n",
     SLAVESTART_MS0042   => "相手のノードに最新のタイムライン履歴ファイルが存在しません: [0]\n",
-    SLAVESTART_MS0043   => "相手のノードの TimeLineID に対応するタイムライン履歴ファイル \"[0]\" に自身のノードの TimeLineID を通った履歴が残っていません\n",
-    SLAVESTART_MS0044   => "相手のノードの TimeLineID に対応するタイムライン履歴ファイル \"[0]\" に自身のノードの TimeLineID の XLOG の位置を通った履歴が残っていません\n",
+    SLAVESTART_MS0043   => "相手のノードのタイムラインIDに対応するタイムライン履歴ファイル \"[0]\" に自身のノードのタイムラインIDを通った履歴が残っていません\n",
+    SLAVESTART_MS0044   => "相手ノードは自身のノードのLSNより以前に昇格しています\n",
     SLAVESTART_MS0045   => "自身のノードをベースバックアップから再構築してください\n",
     SLAVESTART_MS0046   => "Pacemaker 起動確認処理のタイムアウト時間([0]秒)を経過したためスクリプトを終了します\n",
     SLAVESTART_MS0047   => "[0] の同期レプリケーション状態が確立されていません\n".
                            "[0] の状態を確認してください\n",
     SLAVESTART_MS0048   => "[0] が起動していません\n".
-                           "Pacemaker の状態の詳細は、crm_mon コマンドを実行して確認してください\n",
+                           "Pacemaker の状態の詳細は、crm_mon コマンドで確認してください\n",
     SLAVESTART_MS0049   => "アーカイブディレクトリのタイムライン履歴ファイルが処理できません (未知の拡張子: [0])\n",
+    SLAVESTART_MS0050   => "[0].[1] 現在のDBクラスタのまま起動が可能か確認\n",
+    SLAVESTART_MS0051   => "[0].[1] 巻き戻しを実行することで起動が可能か確認\n",
+    SLAVESTART_MS0052   => "[0].[1] ベースバックアップを取得することが可能か確認\n",
+    SLAVESTART_MS0053   => "自身のノードと相手のノードのタイムラインID([0])の分岐点が異なっています\n",
+    SLAVESTART_MS0054   => "自身のノードに recovery.conf ファイルが存在します: [0]\n",
+    SLAVESTART_MS0055   => "相手ノードの full_page_writes は有効である必要があります\n",
+    SLAVESTART_MS0056   => "DBクラスタが --data-checksums 付きで作成されているか、wal_log_hints が on である必要があります\n",
+    SLAVESTART_MS0057   => "pg_rewind を実行可能な状態にできません - pg_rewind 以外の方法を使ってください\n",
+    SLAVESTART_MS0058   => "\n指定された起動方法に実行可能なものがありませんでした\n",
+    SLAVESTART_MS0059   => "\n以下の方法で起動が可能です\n",
+    SLAVESTART_MS0060   => "n) 現在のDBクラスタのままSlaveを起動\n",
+    SLAVESTART_MS0061   => "r) 現在のDBクラスタを巻き戻してSlaveを起動\n",
+    SLAVESTART_MS0062   => "b) ベースバックアップを取得してSlaveを起動\n",
+    SLAVESTART_MS0063   => "q) Slaveの起動を中止する\n",
+    SLAVESTART_MS0064   => "起動方法を選択してください([0]) ",
+    SLAVESTART_MS0065   => "Slave の起動処理を中止します\n",
+    SLAVESTART_MS0066   => "選択範囲外の入力がありました\n",
+    SLAVESTART_MS0067   => "\n現在のDBクラスタのまま起動します。\n\n",
+    SLAVESTART_MS0068   => "\n巻き戻し実行後に起動します。\n\n",
+    SLAVESTART_MS0069   => "\nベースバックアップ取得後に起動します。\n\n",
+    SLAVESTART_MS0070   => "[0]. DBクラスタの巻き戻し\n",
+    SLAVESTART_MS0071   => "自身のノードを巻き戻します\n",
+    SLAVESTART_MS0072   => "相手ノードとの分岐点まで状態を戻すことができないため pg_rewind は利用できません\n",
+    SLAVESTART_MS0073   => "ssh の接続に失敗しました([0])\n - 巻き戻しを中断します\n",
+    SLAVESTART_MS0074   => "pg_rewind が相手のノードへの接続に失敗しました\n - 相手ノードの sshd_config で TCP Forwarding が無効になっている可能性があります\n",
+    SLAVESTART_MS0075   => "pg-rex_slave_startで巻き戻しに失敗したDBクラスタです。\n",
+    SLAVESTART_MS0076   => "アーカイブディレクトリに相手のノードの XLOG の位置よりも進んだ WAL ファイルが存在します\n",
+    SLAVESTART_MS0099   => "内部エラー\n",
 
     STOP_USAGE  => <<_STOP_USAGE_,
 PG-REX の Master または Slave を停止するツールです
@@ -167,7 +196,7 @@ _STOP_USAGE_
     STOP_MS0012         => "2. Pacemaker 停止確認\n",
     STOP_MS0013         => "...[NG]\n",
     STOP_MS0014         => "Pacemaker の停止確認処理のタイムアウト時間([0]秒)を経過したのでスクリプトを終了します\n".
-                           "ps コマンドを用いて Pacemaker および Corosync のプロセスが正常に停止されているかを確認してください\n",
+                           "Pacemaker および Corosync のプロセスが正常に停止されているかを確認してください\n",
     STOP_MS0015         => "ノード([0])で Pacemaker を停止しました\n",
     STOP_MS0016         => "PG-REX の [0] ([1])を停止しました\n",
     STOP_MS0018         => "Slave がまだ起動しています\n",
@@ -186,22 +215,22 @@ Hostname        ベースバックアップが存在するリモートサーバ
 BasebackupPath  ベースバックアップの場所の絶対パスを指定します
 
 Options:
-  -m, --move                         mv モードで実行します
-  -r, --remove                       rm モードで実行します
+  -m, --move                         移動モードで実行します
+  -r, --remove                       削除モードで実行します
   -f, --force                        アーカイブログの削除を問い合わせ無しで
                                      実行します
-  -D, --dbcluster=DBclusterFilepath  DB クラスタの場所の絶対パスを
-                                     指定します
+  -D, --dbcluster=DBclusterFilepath  両系で使用している DB クラスタの場所の
+                                     絶対パスを指定します
   -h, --help                         Usage を表示して終了します
   -v, --version                      バージョン情報を表示して終了します
 
 _ARCDELETE_USAGE_
     
     ARCHDELETE_MS0001   => "Ctrl+C は本プログラムでは無効です\n",
-    ARCHDELETE_MS0002   => "mv モードか rm モードのどちらか片方を指定してください\n",
+    ARCHDELETE_MS0002   => "移動モードか 削除モードのどちらか片方を指定してください\n",
     ARCHDELETE_MS0003   => "\n**** 1. 実行準備 ****\n",
-    ARCHDELETE_MS0004   => "mv モードで実行します\n",
-    ARCHDELETE_MS0005   => "rm モードで実行します\n",
+    ARCHDELETE_MS0004   => "移動モードで実行します\n",
+    ARCHDELETE_MS0005   => "削除モードで実行します\n",
     ARCHDELETE_MS0006   => "バックアップパスのフォーマットが不正です : \"[0]\"\n",
     ARCHDELETE_MS0007   => "ベースバックアップが存在するリモートサーバを入力してください\n".
                            "(入力しなければ \"localhost\" を設定します)\n".
@@ -242,11 +271,11 @@ _ARCDELETE_USAGE_
     ARCHDELETE_MS0036   => "移動先ディレクトリ \"[0]\" の postgres ユーザへの変更に失敗しました\n",
     ARCHDELETE_MS0037   => "移動先ディレクトリ \"[0]\" を作成しました\n",
     ARCHDELETE_MS0038   => "ファイル \"[0]\" の移動に失敗しました\n",
-    ARCHDELETE_MS0039   => " -- mv -- [0] \n",
+    ARCHDELETE_MS0039   => " -- 移動 -- [0] \n",
     ARCHDELETE_MS0040   => "アーカイブログの移動に成功しました\n".
-                           "mv モード実行のため、移動したファイルは \"[0]\" に格納されています\n",
+                           "移動モード実行のため、移動したファイルは \"[0]\" に格納されています\n",
     ARCHDELETE_MS0041   => "ファイル \"[0]\" の削除に失敗しました\n",
-    ARCHDELETE_MS0042   => " -- rm -- [0] \n",
+    ARCHDELETE_MS0042   => " -- 削除 -- [0] \n",
     ARCHDELETE_MS0043   => "アーカイブログの削除に成功しました\n",
     ARCHDELETE_MS0044   => "DB クラスタの場所の絶対パスを取得できませんでした\n".
                            "-D オプションで DB クラスタの場所の絶対パスを指定してください\n",
@@ -290,10 +319,10 @@ _SWITCHOVER_USAGE_
     SWITCHOVER_MS0022   => "[0]. [1] が新 Master になったことを確認\n",
     SWITCHOVER_MS0023   => "リソース起動確認処理のタイムアウト時間([0]秒)を経過したためスクリプトを終了します\n".
                            "[1] が起動していません\n".
-                           "Pacemaker の状態の詳細は、crm_mon コマンドを実行して確認してください\n",
+                           "Pacemaker の状態の詳細は、crm_mon コマンドで確認してください\n",
     SWITCHOVER_MS0026   => "[0]. [1] の Pacemaker を停止\n",
     SWITCHOVER_MS0027   => "Pacemaker の停止確認処理のタイムアウト時間([0]秒)を経過したのでスクリプトを終了します\n".
-                           "Pacemaker の状態の詳細は、crm_mon コマンドを実行して確認してください\n",
+                           "Pacemaker の状態の詳細は、crm_mon コマンドで確認してください\n",
     SWITCHOVER_MS0028   => "[0]. [1] で Slave を起動\n",
     SWITCHOVER_MS0030   => "**** [0] が Slave として起動しました ****\n",
     SWITCHOVER_MS0031   => "****************************************\n".
